@@ -15,12 +15,17 @@
 #include "../DasherTypes.h"
 #include "GroupInfo.h"
 
+#include <cstdlib>
 #include <vector>
 #include "AlphabetMap.h"
 #include "AlphIO.h"
 
 namespace Dasher {
 
+  ///
+  /// \defgroup Alphabet Alphabet information
+  /// @{
+
   class CAlphabet {
   public:
 
@@ -190,6 +195,8 @@ namespace Dasher {
     //    friend class CGroupAdder;
   };
 
+  /// @}
+
   inline symbol CAlphabet::GetParagraphSymbol() const {
     return m_ParagraphSymbol;
   }
