@@ -11,20 +11,18 @@
 
 #include "DasherTypes.h"
 
+#ifdef _WIN32
+#include "../Common/Expat/lib/expat.h"
+#else
+#include <expat.h>
+#endif
+
 #include <string>
 #include <map>
 #include <vector>
 #include <utility>              // for std::pair
 #include <stdio.h>              // for C style file IO
 
-/// \cond expat
-
-namespace expat {
-#include "../Common/Expat/lib/expat.h"
-}
-
-/// \endcond
-
 namespace Dasher {
   class CColourIO;
 }
@@ -77,9 +75,9 @@ private:
 
   // Callback functions. These involve the normal dodgy casting to a pointer
   // to an instance to get a C++ class to work with a plain C library.
-  static void XML_StartElement(void *userData, const expat::XML_Char * name, const expat::XML_Char ** atts);
-  static void XML_EndElement(void *userData, const expat::XML_Char * name);
-  static void XML_CharacterData(void *userData, const expat::XML_Char * s, int len);
+  static void XML_StartElement(void *userData, const XML_Char * name, const XML_Char ** atts);
+  static void XML_EndElement(void *userData, const XML_Char * name);
+  static void XML_CharacterData(void *userData, const XML_Char * s, int len);
 };
 /// @}
 
