@@ -202,12 +202,6 @@ public:
   void PreSetNotify(int iParameter, const std::string &sValue);
 
 
-  /// Draw a new Dasher frame, regardless of whether we're paused etc.
-  /// \param iTime Current time in ms.
-  /// \param bForceRedraw 
-  /// \todo See comments in cpp file for some functionality which needs to be re-implemented
-  void NewFrame(unsigned long iTime, bool bForceRedraw);
-
 
   /// @name Starting and stopping
   /// Methods used to instruct dynamic motion of Dasher to start or stop
@@ -354,6 +348,12 @@ public:
   std::string GetContext(int iStart, int iLength);
 
   void SetControlOffset(int iOffset);
+
+  /// Set a key value pair by name - designed to allow operation from
+  /// the command line
+  ///
+  void ClSet(const std::string &strKey, const std::string &strValue);
+
 protected:
 
   /// @name Startup
@@ -376,6 +376,15 @@ protected:
 
   /// @}
 
+
+
+  /// Draw a new Dasher frame, regardless of whether we're paused etc.
+  /// \param iTime Current time in ms.
+  /// \param bForceRedraw 
+  /// \todo See comments in cpp file for some functionality which needs to be re-implemented
+  void NewFrame(unsigned long iTime, bool bForceRedraw);
+
+
   enum ETransition {
     TR_MODEL_INIT = 0,
     TR_UI_INIT,
