@@ -1,9 +1,12 @@
+#include "../Common/Common.h"
+
+#include <iostream>
 
 #include "UserLogTrial.h"
 
 // Track memory leaks on Windows to the line that new'd the memory
 #ifdef _WIN32
-#ifdef _DEBUG
+#ifdef _DEBUG_MEMLEAKS
 #define DEBUG_NEW new( _NORMAL_BLOCK, THIS_FILE, __LINE__ )
 #define new DEBUG_NEW
 #undef THIS_FILE
@@ -47,6 +50,17 @@ CUserLogTrial::~CUserLogTrial()
         pCycle->pSpan = NULL;
       }
 
+      for (unsigned int i = 0; i < pCycle->vectorButtons.size(); i++)
+      {
+        CUserButton* pButton = (CUserButton*) pCycle->vectorButtons[i];
+
+        if (pButton != NULL)
+        {
+          delete pButton;
+          pButton = NULL;
+        }
+      }
+
       for (unsigned int i = 0; i < pCycle->vectorMouseLocations.size(); i++)
       {
         CUserLocation* pLocation = (CUserLocation*) pCycle->vectorMouseLocations[i];
@@ -182,11 +196,11 @@ void CUserLogTrial::StartWriting()
       pLastLocation->span->Continue();
   }
 
-  NavCycle* pNewCycle = AddNavCycle();
-
+  //  NavCycle* newCycle = AddNavCycle();
+  AddNavCycle();
 }
 
-void CUserLogTrial::StopWriting()
+void CUserLogTrial::StopWriting(double dBits)
 {
   //CFunctionLogger f1("CUserLogTrial::StopWriting", g_pLogger);
 
@@ -215,6 +229,8 @@ void CUserLogTrial::StopWriting()
     g_pLogger->Log("CUserLogTrial::StopWriting, span was NULL!", logNORMAL);
     return;
   }
+
+  pCycle->dBits = dBits;
   pSpan->Stop();
 
   m_bWritingStart = false;
@@ -280,6 +296,8 @@ void CUserLogTrial::AddSymbols(Dasher::VECTOR_SYMBOL_PROB* vpNewSymbolProbs,
     // a given symbol might take up multiple chars.
     // We also keep the probability around so we can
     // calculate the average bits of the history.
+    std::cout << "Add: " << sNewSymbolProb.sym << " " << sNewSymbolProb.prob << " " << pCurrentAlphabet->GetText(sNewSymbolProb.sym) << std::endl;
+
     m_vHistory.push_back(sNewSymbolProbDisplay);        
   }
 
@@ -325,6 +343,8 @@ void CUserLogTrial::DeleteSymbols(int iNumToDelete, eUserLogEventType iEvent)
   {
     // Remove the request number of symbols from our
     // ongoing list.
+    std::cout << "Pop back" << std::endl;
+
     m_vHistory.pop_back();
   }
 
@@ -432,6 +452,21 @@ void CUserLogTrial::AddMouseLocationNormalized(int iX, int iY, bool bStoreIntege
     g_pLogger->Log("CUserLogTrial::AddLocation, location was NULL!", logNORMAL);    
 }
 
+void CUserLogTrial::AddKeyDown(int iId, int iType, int iEffect) {
+  CUserButton* pButton = new CUserButton(iId, iType, iEffect);
+
+  if(pButton) {
+    NavCycle* pCycle = GetCurrentNavCycle();
+
+    if(pCycle)
+      pCycle->vectorButtons.push_back(pButton);
+    else
+      g_pLogger->Log("CUserLogTrial::AddLocation, cycle was NULL!", logNORMAL);
+  }
+  else
+    g_pLogger->Log("CUserLogTrial::AddLocation, location was NULL!", logNORMAL);
+}
+
 // Sets the current window size, this includes area for the menu bar, 
 // sliders, canvas, etc.
 void CUserLogTrial::AddWindowSize(int iTop, int iLeft, int iBottom, int iRight)
@@ -689,7 +724,10 @@ string CUserLogTrial::GetSummaryXML(const string& strPrefix)
     dAvgBits = pLocation->avgBits;
   }
 
-  strResult += GetStatsXML(strPrefix, strText, m_pSpan, dAvgBits);
+  int iButtonCount = GetButtonCount();
+  double dTotalBits = GetTotalBits();
+
+  strResult += GetStatsXML(strPrefix, strText, m_pSpan, dAvgBits, iButtonCount, dTotalBits);
 
   strResult += strPrefix;
   strResult += "\t</Summary>\n";
@@ -698,7 +736,7 @@ string CUserLogTrial::GetSummaryXML(const string& strPrefix)
 }
 
 // Calculates the various summary stats we output
-string CUserLogTrial::GetStatsXML(const string& strPrefix, const string& strText, CTimeSpan* pSpan, double dAvgBits)
+string CUserLogTrial::GetStatsXML(const string& strPrefix, const string& strText, CTimeSpan* pSpan, double dAvgBits, int iButtonCount, double dTotalBits)
 {
   //CFunctionLogger f1("CUserLogTrial::GetStatsXML", g_pLogger);
 
@@ -722,6 +760,19 @@ string CUserLogTrial::GetStatsXML(const string& strPrefix, const string& strText
   strResult += m_szTempBuffer;
   strResult += "</AvgBits>\n";
 
+  strResult += strPrefix;
+  strResult += "\t\t<TotalBits>";
+  sprintf(m_szTempBuffer, "%0.6f", dTotalBits);
+  strResult += m_szTempBuffer;
+  strResult += "</TotalBits>\n";
+
+  
+  strResult += strPrefix;
+  strResult += "\t\t<ButtonCount>";
+  sprintf(m_szTempBuffer, "%d", iButtonCount);
+  strResult += m_szTempBuffer;
+  strResult += "</ButtonCount>\n";
+
   // Calculate the number of words and characters
   strResult += strPrefix;
   strResult += "\t\t<Chars>";
@@ -857,6 +908,25 @@ string CUserLogTrial::GetParamsXML(const string& strPrefix)
 
 }
 
+int CUserLogTrial::GetButtonCount() {
+  int iCount(0);
+
+  for(VECTOR_NAV_CYCLE_PTR::iterator it(m_vpNavCycles.begin()); it != m_vpNavCycles.end(); ++it)
+    for(VECTOR_USER_BUTTON_PTR::iterator it2((*it)->vectorButtons.begin()); it2 != (*it)->vectorButtons.end(); ++it2)
+      iCount += (*it2)->GetCount();
+
+  return iCount;
+}
+
+double CUserLogTrial::GetTotalBits() {
+  double dBits(0.0);
+
+  for(VECTOR_NAV_CYCLE_PTR::iterator it(m_vpNavCycles.begin()); it != m_vpNavCycles.end(); ++it)
+    dBits += (*it)->dBits;
+
+  return dBits;
+}
+
 // Parameters can optionally be specified to be added to the Trial objects.
 // This allows us to easily see what a certain parameter value was used
 // in a given trial.  
@@ -966,15 +1036,24 @@ NavLocation* CUserLogTrial::GetCurrentNavLocation()
 {
   //CFunctionLogger f1("CUserLogTrial::GetCurrentNavLocation", g_pLogger);
 
-  NavCycle* pCycle = GetCurrentNavCycle();
+//   NavCycle* pCycle = GetCurrentNavCycle();
 
-  if (pCycle == NULL)
-    return NULL;
+//   if (pCycle == NULL)
+//     return NULL;
 
-  if (pCycle->vectorNavLocations.size() <= 0)
-    return NULL;
+//   if (pCycle->vectorNavLocations.size() <= 0)
+//     return NULL;
 
-  return (NavLocation*) pCycle->vectorNavLocations[pCycle->vectorNavLocations.size() - 1];
+//   return (NavLocation*) pCycle->vectorNavLocations[pCycle->vectorNavLocations.size() - 1];
+
+  // New version - reverse iterate through the list and find the last nav cycle which has any locations
+
+  for(VECTOR_NAV_CYCLE_PTR::reverse_iterator it(m_vpNavCycles.rbegin()); it != m_vpNavCycles.rend(); ++it) {
+    if((*it)->vectorNavLocations.size() > 0)
+      return (NavLocation*) (*it)->vectorNavLocations[(*it)->vectorNavLocations.size() - 1];
+  }
+
+  return NULL;
 }
 
 // Adds a new navgiation cycle to our collection
@@ -1063,6 +1142,24 @@ string CUserLogTrial::GetNavCyclesXML(const string& strPrefix)
         strResult += "</MousePositions>\n";
       }
 
+      if (pCycle->vectorButtons.size() > 0)
+      {
+        strResult += strPrefixTabTabTab;
+        strResult += "<Buttons>\n";
+
+        for (unsigned int i = 0; i < pCycle->vectorButtons.size(); i++)
+        {
+          CUserButton* pButton = (CUserButton*) pCycle->vectorButtons[i];
+
+          if(pButton)
+          {
+            strResult += pButton->GetXML(strPrefixTabTabTabTab);
+          }
+        }
+
+        strResult += strPrefixTabTabTab;
+        strResult += "</Buttons>\n";
+      }
 
       strResult += strPrefixTabTab;
       strResult += "</Nav>\n";
