@@ -46,8 +46,8 @@ struct _GtkDasherControlClass {
   void (*dasher_changed) (GtkDasherControl * pDasherControl, gint iParameter, gpointer data);
   void (*dasher_start) (GtkDasherControl * pDasherControl, gpointer data);
   void (*dasher_stop) (GtkDasherControl * pDasherControl, gpointer data);
-  void (*dasher_edit_insert) (GtkDasherControl * pDasherControl, const gchar * szText, gpointer data);
-  void (*dasher_edit_delete) (GtkDasherControl * pDasherControl, const gchar * szText, gpointer data);
+  void (*dasher_edit_insert) (GtkDasherControl * pDasherControl, const gchar * szText, int iOffset, gpointer data);
+  void (*dasher_edit_delete) (GtkDasherControl * pDasherControl, const gchar * szText, int iOffset, gpointer data);
   void (*dasher_edit_convert) (GtkDasherControl * pDasherControl, gpointer data);
   void (*dasher_edit_protect) (GtkDasherControl * pDasherControl, gpointer data);
   void (*dasher_control) (GtkDasherControl * pDasherControl, gint iEvent, gpointer data);
@@ -93,5 +93,7 @@ void gtk_dasher_control_add_action_button(GtkDasherControl *pControl, const gcha
 void gtk_dasher_control_set_control_offset(GtkDasherControl *pControl, gint iOffset);
 void gtk_dasher_user_log_new_trial(GtkDasherControl * pControl);
 void gtk_dasher_control_set_focus(GtkDasherControl * pControl);
+void gtk_dasher_control_cl_set(GtkDasherControl *pControl, const gchar *szKey, const gchar *szValue);
+
 G_END_DECLS
 #endif
