@@ -5,7 +5,7 @@
 
 #include "../Common/Common.h"
 #include "DasherTypes.h"
-#include "FontDialogues.h"
+//#include "FontDialogues.h"
 #include "Preferences.h"
 #include "Parameters.h"
 #include "module_settings_window.h"
@@ -92,7 +92,7 @@ enum {
 
 struct _DasherPreferencesDialoguePrivate {
   GtkWidget *pPreferencesWindow;
-  DasherEditor *pEditor;
+  DasherEditorInternal *pEditor;
   DasherAppSettings *pAppSettings;
   GtkWindow *pMainWindow;
 
@@ -109,6 +109,7 @@ struct _DasherPreferencesDialoguePrivate {
   GtkWidget *pMousePosButton;
   GtkWidget *pMousePosStyle;
   GtkWidget *pActionTreeView;
+  GtkWidget *pNotebook;
 
   // Set this to ignore signals (ie loops coming back from setting widgets in response to parameters having changed)
   bool bIgnoreSignals;
@@ -218,7 +219,7 @@ static void dasher_preferences_dialogue_destroy(GObject *pObject) {
 
 // Public methods
 
-DasherPreferencesDialogue *dasher_preferences_dialogue_new(GladeXML *pGladeWidgets, DasherEditor *pEditor, DasherAppSettings *pAppSettings, GtkWindow *pMainWindow) {
+DasherPreferencesDialogue *dasher_preferences_dialogue_new(GladeXML *pGladeWidgets, DasherEditorInternal *pEditor, DasherAppSettings *pAppSettings, GtkWindow *pMainWindow) {
   DasherPreferencesDialogue *pDasherControl;
   pDasherControl = (DasherPreferencesDialogue *)(g_object_new(dasher_preferences_dialogue_get_type(), NULL));
 
@@ -236,6 +237,7 @@ DasherPreferencesDialogue *dasher_preferences_dialogue_new(GladeXML *pGladeWidge
   pPrivate->pPreferencesWindow = glade_xml_get_widget(pGladeWidgets, "preferences");
 
   pPrivate->pActionTreeView =glade_xml_get_widget(pGladeWidgets, "action_tree_view");
+  pPrivate->pNotebook = glade_xml_get_widget(pGladeWidgets, "notebook1");
 
   gtk_window_set_transient_for(GTK_WINDOW(pPrivate->pPreferencesWindow), pMainWindow);
 
@@ -252,26 +254,31 @@ DasherPreferencesDialogue *dasher_preferences_dialogue_new(GladeXML *pGladeWidge
 
   dasher_preferences_dialogue_populate_actions(pDasherControl);
 
-  InitialiseFontDialogues(pGladeWidgets);
+  //  InitialiseFontDialogues(pGladeWidgets, pAppSettings);
 
   return pDasherControl;
 }
 
-void dasher_preferences_dialogue_show(DasherPreferencesDialogue *pSelf) {
+void dasher_preferences_dialogue_show(DasherPreferencesDialogue *pSelf, gint iPage) {
   DasherPreferencesDialoguePrivate *pPrivate = (DasherPreferencesDialoguePrivate *)(pSelf->private_data);
   // FIXME - REIMPLEMENT
 
   // Keep the preferences window in the correct position relative to the
   // main Dasher window
   
-  gtk_window_set_transient_for(GTK_WINDOW(pPrivate->pPreferencesWindow),pPrivate->pMainWindow);
+  //  gtk_window_set_transient_for(GTK_WINDOW(pPrivate->pPreferencesWindow),pPrivate->pMainWindow);
 #ifdef WITH_MAEMO
 #ifndef WITH_MAEMOFULLSCREEN
-  gtk_window_set_keep_above((pPrivate->pPreferencesWindow), true);
+  // gtk_window_set_keep_above((pPrivate->pPreferencesWindow), true);
 #endif
 #endif
   // TODO: reimplement
   //  gtk_window_set_keep_above(GTK_WINDOW(pPrivate->pPreferencesWindow), dasher_main_topmost(g_pDasherMain));
+
+  if(iPage > 0) {
+    gtk_notebook_set_current_page(GTK_NOTEBOOK(pPrivate->pNotebook), iPage - 1);
+  }
+
   gtk_window_present(GTK_WINDOW(pPrivate->pPreferencesWindow));
 }
 
@@ -677,17 +684,19 @@ static void dasher_preferences_dialogue_populate_special_colour(DasherPreference
 static void dasher_preferences_dialogue_populate_special_dasher_font(DasherPreferencesDialogue *pSelf) {
   DasherPreferencesDialoguePrivate *pPrivate = DASHER_PREFERENCES_DIALOGUE_PRIVATE(pSelf);
 
-  GtkWidget *pDasherFontButton = glade_xml_get_widget(pPrivate->pGladeXML, "dasherfontbutton");
-  PangoFontDescription *pFont = pango_font_description_from_string(dasher_app_settings_get_string(pPrivate->pAppSettings, SP_DASHER_FONT));
-  gtk_widget_modify_font(pDasherFontButton, pFont);
-  gtk_button_set_label(GTK_BUTTON(pDasherFontButton), dasher_app_settings_get_string(pPrivate->pAppSettings, SP_DASHER_FONT));
+  GtkWidget *pDasherFontButton = glade_xml_get_widget(pPrivate->pGladeXML, "dasher_fontbutton");
+
+  gtk_font_button_set_font_name(GTK_FONT_BUTTON(pDasherFontButton), 
+				dasher_app_settings_get_string(pPrivate->pAppSettings, SP_DASHER_FONT));
 }
 
 static void dasher_preferences_dialogue_populate_special_edit_font(DasherPreferencesDialogue *pSelf) {
   DasherPreferencesDialoguePrivate *pPrivate = DASHER_PREFERENCES_DIALOGUE_PRIVATE(pSelf);
 
-  GtkWidget *pEditFontButton = glade_xml_get_widget(pPrivate->pGladeXML, "editfontbutton");
-  gtk_button_set_label(GTK_BUTTON(pEditFontButton), dasher_app_settings_get_string(pPrivate->pAppSettings, APP_SP_EDIT_FONT));
+  GtkWidget *pEditFontButton = glade_xml_get_widget(pPrivate->pGladeXML, "edit_fontbutton");
+
+  gtk_font_button_set_font_name(GTK_FONT_BUTTON(pEditFontButton), 
+				dasher_app_settings_get_string(pPrivate->pAppSettings, APP_SP_EDIT_FONT));
 }
  
 static void dasher_preferences_dialogue_populate_special_fontsize(DasherPreferencesDialogue *pSelf) {
@@ -899,6 +908,22 @@ extern "C" void on_appstyle_changed(GtkWidget *widget, gpointer user_data) {
   }
 }
 
+extern "C" void on_dasher_font_changed(GtkFontButton *pButton, gpointer pUserData) {
+  DasherPreferencesDialoguePrivate *pPrivate = DASHER_PREFERENCES_DIALOGUE_PRIVATE(g_pPreferencesDialogue);
+
+  dasher_app_settings_set_string(pPrivate->pAppSettings, 
+				 SP_DASHER_FONT, 
+				 gtk_font_button_get_font_name(pButton));
+}
+
+extern "C" void on_edit_font_changed(GtkFontButton *pButton, gpointer pUserData) {
+  DasherPreferencesDialoguePrivate *pPrivate = DASHER_PREFERENCES_DIALOGUE_PRIVATE(g_pPreferencesDialogue);
+
+  dasher_app_settings_set_string(pPrivate->pAppSettings, 
+				 APP_SP_EDIT_FONT, 
+				 gtk_font_button_get_font_name(pButton));
+}
+
 // --- Actions Selection ---
 
 // Note - for now consider the actions configuration to be *really* a
@@ -913,9 +938,9 @@ void dasher_preferences_dialogue_populate_actions(DasherPreferencesDialogue *pSe
 
   GtkTreeIter oIter;
 
-  dasher_editor_actions_start(pPrivate->pEditor);
+  dasher_editor_internal_actions_start(pPrivate->pEditor);
 
-  while(dasher_editor_actions_more(pPrivate->pEditor)) {
+  while(dasher_editor_internal_actions_more(pPrivate->pEditor)) {
     gtk_list_store_append(pPrivate->pListStore, &oIter);
 
     const gchar *szName;
@@ -924,7 +949,7 @@ void dasher_preferences_dialogue_populate_actions(DasherPreferencesDialogue *pSe
     gboolean bControl;
     gboolean bAuto;
 
-    dasher_editor_actions_get_next(pPrivate->pEditor, &szName, &iID, &bShow, &bControl, &bAuto),
+    dasher_editor_internal_actions_get_next(pPrivate->pEditor, &szName, &iID, &bShow, &bControl, &bAuto),
 
     gtk_list_store_set(pPrivate->pListStore, &oIter, 
 		       ACTIONS_ID_COLUMN, iID,
@@ -987,17 +1012,30 @@ extern "C" void on_action_toggle(GtkCellRendererToggle *pRenderer, gchar *szPath
 
 //   switch(*pColumnIndex) {
 //   case ACTIONS_SHOW_COLUMN:
-//     dasher_editor_action_set_show(g_pEditor, iID, !bSelected);
+//     dasher_editor_internal_action_set_show(g_pEditor, iID, !bSelected);
 //     break;
 //   case ACTIONS_CONTROL_COLUMN:
-//     dasher_editor_action_set_control(g_pEditor, iID, !bSelected);
+//     dasher_editor_internal_action_set_control(g_pEditor, iID, !bSelected);
 //     break;
 //   case ACTIONS_AUTO_COLUMN:
-//     dasher_editor_action_set_auto(g_pEditor, iID, !bSelected);
+//     dasher_editor_internal_action_set_auto(g_pEditor, iID, !bSelected);
 //     break;
 //   }
 }
 
+extern "C" void set_dasher_fontsize(GtkWidget *pWidget, gboolean pUserData) {
+  DasherPreferencesDialoguePrivate *pPrivate = DASHER_PREFERENCES_DIALOGUE_PRIVATE(g_pPreferencesDialogue);
+
+  int iValue = dasher_app_settings_get_long(pPrivate->pAppSettings, LP_DASHER_FONTSIZE);
+
+  if((iValue != Opts::Normal) && gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON(glade_xml_get_widget(pPrivate->pGladeXML, "fontsizenormal"))))
+    dasher_app_settings_set_long(pPrivate->pAppSettings, LP_DASHER_FONTSIZE, Opts::Normal);
+  else if((iValue != Opts::Big) && gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON(glade_xml_get_widget(pPrivate->pGladeXML, "fontsizelarge"))))
+    dasher_app_settings_set_long(pPrivate->pAppSettings, LP_DASHER_FONTSIZE, Opts::Big);
+  else if((iValue != Opts::VBig) && gtk_toggle_button_get_active( GTK_TOGGLE_BUTTON(glade_xml_get_widget(pPrivate->pGladeXML, "fontsizevlarge"))))
+    dasher_app_settings_set_long(pPrivate->pAppSettings, LP_DASHER_FONTSIZE, Opts::VBig);
+}
+
 
 // --- General Callbacks ---
 
