@@ -22,6 +22,10 @@
 /* Static instance of singleton, USE SPARINGLY */
 static DasherMain *g_pDasherMain = NULL; 
 
+// TODO: The following global variable makes control mode editing work
+// - this needs to be sorted out properly.
+static gboolean g_bSend = true;
+
 struct _DasherMainPrivate {
   // The glade XML file - TODO: this shouldn't be kept after interface has been loaded
   GladeXML *pGladeXML;
@@ -29,7 +33,7 @@ struct _DasherMainPrivate {
   // Child objects owned here
   DasherAppSettings *pAppSettings;
   DasherPreferencesDialogue *pPreferencesDialogue;
-  DasherEditor *pEditor;
+  DasherEditorInternal *pEditor;
 
   CKeyboardHelper *pKeyboardHelper;
 
@@ -130,6 +134,7 @@ static void dasher_main_menu_command(DasherMain *pSelf, GtkWidget *pWidget);
 static void dasher_main_command_import(DasherMain *pSelf);
 static void dasher_main_command_quit(DasherMain *pSelf);
 static void dasher_main_command_preferences(DasherMain *pSelf);
+static void dasher_main_command_preferences_alphabet(DasherMain *pSelf);
 static void dasher_main_command_tutorial(DasherMain *pSelf);
 static void dasher_main_command_help(DasherMain *pSelf);
 static void dasher_main_command_about(DasherMain *pself);
@@ -158,14 +163,15 @@ gboolean grab_focus();
 
 /* Callback functions */
 extern "C" GtkWidget *create_dasher_control(gchar *szName, gchar *szString1, gchar *szString2, gint iInt1, gint iInt2);
+extern "C" GtkWidget *create_dasher_editor(gchar *szName, gchar *szString1, gchar *szString2, gint iInt1, gint iInt2);
 
 /* ... Message handling from main window widgets */
 extern "C" gboolean dasher_main_cb_menu_command(GtkWidget *pWidget, gpointer pUserData);
 extern "C" gboolean speed_changed(GtkWidget *pWidget, gpointer user_data);
 extern "C" void alphabet_combo_changed(GtkWidget *pWidget, gpointer pUserData);
-extern "C" void dasher_main_cb_filename_changed(DasherEditor *pEditor, gpointer pUserData);
-extern "C" void dasher_main_cb_buffer_changed(DasherEditor *pEditor, gpointer pUserData);
-extern "C" void dasher_main_cb_context_changed(DasherEditor *pEditor, gpointer pUserData);
+extern "C" void dasher_main_cb_filename_changed(DasherEditorInternal *pEditor, gpointer pUserData);
+extern "C" void dasher_main_cb_buffer_changed(DasherEditorInternal *pEditor, gpointer pUserData);
+extern "C" void dasher_main_cb_context_changed(DasherEditorInternal *pEditor, gpointer pUserData);
 extern "C" gboolean dasher_main_cb_window_close(GtkWidget *pWidget, gpointer pUserData);
 extern "C" void parameter_notification(GtkDasherControl *pDasherControl, gint iParameter, gpointer data);
 
@@ -236,6 +242,8 @@ dasher_main_finalize(GObject *pObject) {
   if(pPrivate->pAppSettings)
     g_object_unref(pPrivate->pAppSettings);
 
+  gtk_widget_destroy(pPrivate->pMainWindow);
+
   /* TDO: Do we need to take down anything else? */
 }
 
@@ -276,6 +284,45 @@ dasher_main_new(int *argc, char ***argv, SCommandLine *pCommandLine) {
     dasher_main_load_interface(pDasherMain);
 
     dasher_app_settings_set_widget(pPrivate->pAppSettings, GTK_DASHER_CONTROL(pPrivate->pDasherWidget));
+
+
+    /* TODO: This parsing code should really be tidied up */
+    if(pCommandLine && pCommandLine->szOptions) {
+      gchar **pszOptionTerms;
+      pszOptionTerms = g_strsplit(pCommandLine->szOptions, ",", 0);
+
+      gchar **pszCurrent = pszOptionTerms;
+
+      while(*pszCurrent) {
+	gchar *szJoin = g_strrstr(*pszCurrent, "=");
+
+	if(szJoin) {
+	  int iLength = szJoin - *pszCurrent;
+	  
+	  gchar *szKey = g_new(gchar, iLength + 1);
+	  memcpy(szKey, *pszCurrent, iLength);
+	  szKey[iLength] = '\0';
+	  
+	  dasher_app_settings_cl_set(pPrivate->pAppSettings, szKey, szJoin + 1);
+	  
+	  g_free(szKey);
+	}
+	else {
+	  g_error("Invalid option string specified");
+	}
+
+	++pszCurrent;
+      }
+
+      g_strfreev(pszOptionTerms);
+    }
+    /* --- */
+
+
+
+    dasher_editor_internal_initialise(pPrivate->pEditor, pPrivate->pAppSettings, pDasherMain, pPrivate->pGladeXML, NULL);
+
+
     dasher_main_setup_window(pDasherMain);
 
     /* Create the editor */
@@ -295,13 +342,18 @@ dasher_main_new(int *argc, char ***argv, SCommandLine *pCommandLine) {
       }
     }
 
-    pPrivate->pEditor = dasher_editor_new(pPrivate->pAppSettings, pDasherMain, pPrivate->pGladeXML, szFullPath);
+    // TODO: Fix this
+//     pPrivate->pEditor = GTK_EDITOR(
+
+
+// dasher_editor_initialise(pPrivate->pAppSettings, pDasherMain, pPrivate->pGladeXML, szFullPath);
 
     g_free(szFullPath);
 
-    g_signal_connect(pPrivate->pEditor, "filename_changed", G_CALLBACK(dasher_main_cb_filename_changed), pDasherMain);
-    g_signal_connect(pPrivate->pEditor, "buffer_changed", G_CALLBACK(dasher_main_cb_buffer_changed), pDasherMain);
-    g_signal_connect(pPrivate->pEditor, "context_changed", G_CALLBACK(dasher_main_cb_context_changed), pDasherMain);
+    // TODO: Were these really needed?
+    //    g_signal_connect(pPrivate->pEditor, "filename_changed", G_CALLBACK(dasher_main_cb_filename_changed), pDasherMain);
+    //    g_signal_connect(pPrivate->pEditor, "buffer_changed", G_CALLBACK(dasher_main_cb_buffer_changed), pDasherMain);
+    //    g_signal_connect(pPrivate->pEditor, "context_changed", G_CALLBACK(dasher_main_cb_context_changed), pDasherMain);
 
     /* Create the preferences window */
     dasher_main_create_preferences(pDasherMain);
@@ -484,9 +536,9 @@ dasher_main_load_interface(DasherMain *pSelf) {
 
   // TODO: Specify callbacks in glade file
   // TODO: Rationalise focus
-  g_signal_connect(G_OBJECT(pPrivate->pBufferView), "button-release-event", G_CALLBACK(take_real_focus), NULL);
-  g_signal_connect(G_OBJECT(pPrivate->pBufferView), "key-press-event", G_CALLBACK(edit_key_press), NULL);
-  g_signal_connect(G_OBJECT(pPrivate->pBufferView), "key-release-event", G_CALLBACK(edit_key_release), NULL);
+  //  g_signal_connect(G_OBJECT(pPrivate->pBufferView), "button-release-event", G_CALLBACK(take_real_focus), NULL);
+  // g_signal_connect(G_OBJECT(pPrivate->pBufferView), "key-press-event", G_CALLBACK(edit_key_press), NULL);
+  //g_signal_connect(G_OBJECT(pPrivate->pBufferView), "key-release-event", G_CALLBACK(edit_key_release), NULL);
 
   pPrivate->iAlphabetComboHandler = g_signal_connect(G_OBJECT(pPrivate->pAlphabetCombo), "changed", G_CALLBACK(alphabet_combo_changed), NULL);
   
@@ -504,6 +556,9 @@ dasher_main_load_interface(DasherMain *pSelf) {
   
   dasher_main_connect_menus(pSelf);
 
+
+  pPrivate->pEditor = DASHER_EDITOR_INTERNAL(glade_xml_get_widget(pPrivate->pGladeXML, "DasherEditor"));
+  // TODO: szFullPath
   pPrivate->bWidgetsInitialised = true;
 }
 
@@ -513,7 +568,7 @@ dasher_main_create_preferences(DasherMain *pSelf) {
   pPrivate->pPreferencesDialogue = dasher_preferences_dialogue_new(pPrivate->pGladeXML, pPrivate->pEditor, pPrivate->pAppSettings, GTK_WINDOW(pPrivate->pMainWindow));
 }
 
-// DasherEditor *
+// DasherEditorInternal *
 // dasher_main_get_editor(DasherMain *pSelf) {
 //   DasherMainPrivate *pPrivate = DASHER_MAIN_GET_PRIVATE(pSelf);
 //   return pPrivate->pEditor;
@@ -537,6 +592,7 @@ dasher_main_handle_parameter_change(DasherMain *pSelf, int iParameter) {
       gtk_widget_hide(pPrivate->pStatusControl);
     break;
   case APP_SP_EDIT_FONT:
+    // TODO: Editor should handle this directly
     dasher_main_refresh_font(pSelf);
     break;
 #ifndef WITH_MAEMO
@@ -747,6 +803,11 @@ dasher_main_command(DasherMain *pSelf, const gchar *szCommand) {
     return TRUE;
   }
 
+  if(!strcmp(szCommand, "preferences_alphabet")) {
+    dasher_main_command_preferences_alphabet(pSelf);
+    return TRUE;
+  }
+
   if(!strcmp(szCommand, "tutorial")) {
     dasher_main_command_tutorial(pSelf);
     return TRUE;
@@ -763,7 +824,7 @@ dasher_main_command(DasherMain *pSelf, const gchar *szCommand) {
   }
 
   if(pPrivate->pEditor)
-    return dasher_editor_command(pPrivate->pEditor, szCommand);
+    return dasher_editor_internal_command(pPrivate->pEditor, szCommand);
 
   return FALSE;
 }
@@ -797,6 +858,9 @@ dasher_main_setup_window_style(DasherMain *pSelf) {
 
     // Refuse focus
     gtk_window_set_accept_focus(GTK_WINDOW(pPrivate->pMainWindow), false);
+
+    // Stick on all desktops
+    gtk_window_stick(GTK_WINDOW(pPrivate->pMainWindow));
     break;
   case 3:
     // Fullscreen mode - set fullscreen
@@ -833,12 +897,8 @@ static void
 dasher_main_refresh_font(DasherMain *pSelf) {
   DasherMainPrivate *pPrivate = DASHER_MAIN_GET_PRIVATE(pSelf);
 
-  const gchar *szFontName = dasher_app_settings_get_string(pPrivate->pAppSettings, APP_SP_EDIT_FONT);
-  PangoFontDescription *pFD = pango_font_description_from_string(szFontName);
-
-  if(strcmp(szFontName, "")) {
-    gtk_widget_modify_font(pPrivate->pBufferView, pFD);
-  }
+  dasher_editor_internal_handle_font(pPrivate->pEditor, 
+			    dasher_app_settings_get_string(pPrivate->pAppSettings, APP_SP_EDIT_FONT));
 }
 
 // TODO: Fold into setup controls?
@@ -846,7 +906,7 @@ static void
 dasher_main_set_filename(DasherMain *pSelf) {
   DasherMainPrivate *pPrivate = DASHER_MAIN_GET_PRIVATE(pSelf);
 
-  const gchar *szFilename = dasher_editor_get_filename(pPrivate->pEditor);
+  const gchar *szFilename = dasher_editor_internal_get_filename(pPrivate->pEditor);
 
   if(szFilename == 0) {
     gtk_window_set_title(GTK_WINDOW(pPrivate->pMainWindow), "Dasher");
@@ -927,8 +987,8 @@ static void dasher_main_command_quit(DasherMain *pSelf) {
 
   GtkWidget *pDialogue = NULL;
 
-  if(dasher_editor_file_changed(pPrivate->pEditor)) {
-    const gchar *szFilename = dasher_editor_get_filename(pPrivate->pEditor);
+  if(dasher_editor_internal_file_changed(pPrivate->pEditor)) {
+    const gchar *szFilename = dasher_editor_internal_get_filename(pPrivate->pEditor);
 
     if(szFilename) {
       pDialogue = gtk_message_dialog_new(GTK_WINDOW(pPrivate->pMainWindow), GTK_DIALOG_MODAL, 
@@ -977,7 +1037,13 @@ static void dasher_main_command_quit(DasherMain *pSelf) {
 static void 
 dasher_main_command_preferences(DasherMain *pSelf) { 
   DasherMainPrivate *pPrivate = DASHER_MAIN_GET_PRIVATE(pSelf);
-  dasher_preferences_dialogue_show(pPrivate->pPreferencesDialogue);
+  dasher_preferences_dialogue_show(pPrivate->pPreferencesDialogue, 0);
+}
+
+static void 
+dasher_main_command_preferences_alphabet(DasherMain *pSelf) { 
+  DasherMainPrivate *pPrivate = DASHER_MAIN_GET_PRIVATE(pSelf);
+  dasher_preferences_dialogue_show(pPrivate->pPreferencesDialogue, 1);
 }
 
 static void 
@@ -999,7 +1065,8 @@ dasher_main_command_about(DasherMain *pSelf) {
 
 #if (defined GNOME_LIBS) || (GTK_CHECK_VERSION(2,6,0))
 
-  // In alphabetical order
+  // In alphabetical order - please keep this in sync with the AUTHORS
+  // file at root of the package tree
   const gchar *authors[] = {
     "Chris Ball",
     "Ignas Budvytis",
@@ -1010,7 +1077,9 @@ dasher_main_command_about(DasherMain *pSelf) {
     "Chris Hack",
     "David MacKay",
     "Iain Murray",
+    "Sega Kazue",
     "Takashi Kaburagi",
+    "Martijn van Veen",
     "Keith Vertanen",
     "Hanna Wallach",
     "David Ward",
@@ -1117,7 +1186,7 @@ dasher_main_alphabet_combo_changed(DasherMain *pSelf) {
   if(!strcmp("More Alphabets...", szSelected)) {
     gtk_combo_box_set_active(GTK_COMBO_BOX(pPrivate->pAlphabetCombo), 0);
     //    dasher_preferences_dialogue_show(pPrivate->pPreferencesDialogue);
-    dasher_main_command(pSelf, "preferences");
+    dasher_main_command(pSelf, "preferences_alphabet");
   }
   else 
     dasher_app_settings_set_string(pPrivate->pAppSettings, SP_ALPHABET_ID, szSelected);
@@ -1213,6 +1282,11 @@ create_dasher_control(gchar *szName, gchar *szString1, gchar *szString2, gint iI
   return pDasherControl;
 }
 
+extern "C" GtkWidget *
+create_dasher_editor(gchar *szName, gchar *szString1, gchar *szString2, gint iInt1, gint iInt2) {
+  return GTK_WIDGET(dasher_editor_internal_new());
+}
+
 extern "C" gboolean 
 dasher_main_cb_menu_command(GtkWidget *pWidget, gpointer pUserData) {
   dasher_main_menu_command((DasherMain *)pUserData, pWidget);
@@ -1236,24 +1310,33 @@ alphabet_combo_changed(GtkWidget *pWidget, gpointer pUserData) {
 }
 
 extern "C" void 
-dasher_main_cb_filename_changed(DasherEditor *pEditor, gpointer pUserData) {
-  dasher_main_set_filename(DASHER_MAIN(pUserData));
+dasher_main_cb_filename_changed(DasherEditorInternal *pEditor, gpointer pUserData) {
+  if(g_pDasherMain)
+    dasher_main_set_filename(g_pDasherMain);
 }
 
 extern "C" void 
-dasher_main_cb_buffer_changed(DasherEditor *pEditor, gpointer pUserData) {
-  DasherMain *pDasherMain = DASHER_MAIN(pUserData);
-  DasherMainPrivate *pPrivate = DASHER_MAIN_GET_PRIVATE(pDasherMain);
+dasher_main_cb_buffer_changed(DasherEditorInternal *pEditor, gpointer pUserData) {
+  if(!g_pDasherMain)
+    return;
 
-  gtk_dasher_control_set_buffer(GTK_DASHER_CONTROL(pPrivate->pDasherWidget), dasher_editor_get_offset(pPrivate->pEditor));
+  DasherMainPrivate *pPrivate = DASHER_MAIN_GET_PRIVATE(g_pDasherMain);
+
+  gtk_dasher_control_set_buffer(GTK_DASHER_CONTROL(pPrivate->pDasherWidget), dasher_editor_internal_get_offset(pPrivate->pEditor));
 }
 
 extern "C" void 
-dasher_main_cb_context_changed(DasherEditor *pEditor, gpointer pUserData) {
-  DasherMain *pDasherMain = DASHER_MAIN(pUserData);
+dasher_main_cb_context_changed(DasherEditorInternal *pEditor, gpointer pUserData) {
+  if(!g_pDasherMain)
+    return;
+
+  if(!g_bSend)
+    return;
+
+  DasherMain *pDasherMain = DASHER_MAIN(g_pDasherMain);
   DasherMainPrivate *pPrivate = DASHER_MAIN_GET_PRIVATE(pDasherMain);
 
-  gtk_dasher_control_set_offset(GTK_DASHER_CONTROL(pPrivate->pDasherWidget), dasher_editor_get_offset(pPrivate->pEditor));
+  gtk_dasher_control_set_offset(GTK_DASHER_CONTROL(pPrivate->pDasherWidget), dasher_editor_internal_get_offset(pPrivate->pEditor));
 }
 
 extern "C" gboolean 
@@ -1336,7 +1419,7 @@ handle_context_request(GtkDasherControl * pDasherControl, gint iOffset, gint iLe
   if(!pPrivate->pEditor || !pPrivate->pDasherWidget)
     return;
 
-  gtk_dasher_control_set_context(GTK_DASHER_CONTROL(pPrivate->pDasherWidget), dasher_editor_get_context(pPrivate->pEditor, iOffset, iLength));
+  gtk_dasher_control_set_context(GTK_DASHER_CONTROL(pPrivate->pDasherWidget), dasher_editor_internal_get_context(pPrivate->pEditor, iOffset, iLength));
 }
 
 extern "C" void 
@@ -1349,18 +1432,33 @@ handle_control_event(GtkDasherControl *pDasherControl, gint iEvent, gpointer dat
   switch(iEvent) {
   case Dasher::CControlManager::CTL_USER + 1:
     dasher_main_command(g_pDasherMain, "speakall");
-    break;
+    return;
   case Dasher::CControlManager::CTL_USER + 2:
     dasher_main_command(g_pDasherMain, "speaklast");
-    break;
+    return;
   case Dasher::CControlManager::CTL_USER + 3:
     dasher_main_command(g_pDasherMain, "speakrepeat");
-    break;
+    return;
   default:
     break;
   }
+
+
+  // TODO: This is a horrible hack here to make the release work!  
+
+  g_bSend = false;
+
+  DasherMainPrivate *pPrivate = DASHER_MAIN_GET_PRIVATE(g_pDasherMain);
+  dasher_editor_internal_handle_control(pPrivate->pEditor, iEvent);
+
+  gtk_dasher_control_set_control_offset(GTK_DASHER_CONTROL(pPrivate->pDasherWidget), 
+					dasher_editor_internal_get_offset(pPrivate->pEditor));
+
+  g_bSend = true;
+  // ---
 }
 
+
 extern "C" void 
 handle_start_event(GtkDasherControl *pDasherControl, gpointer data) { 
   if(!g_pDasherMain)
@@ -1368,7 +1466,7 @@ handle_start_event(GtkDasherControl *pDasherControl, gpointer data) {
 
   DasherMainPrivate *pPrivate = DASHER_MAIN_GET_PRIVATE(g_pDasherMain);
   
-  dasher_editor_grab_focus(pPrivate->pEditor);
+  dasher_editor_internal_grab_focus(pPrivate->pEditor);
 }
 
 
@@ -1381,15 +1479,20 @@ dasher_main_key_snooper(GtkWidget *pWidget, GdkEventKey *pEvent, gpointer pUserD
   
   if(iButton != -1) {
     DasherMainPrivate *pPrivate = DASHER_MAIN_GET_PRIVATE(pSelf);
-    
-    if(pPrivate->pDasherWidget) {
-      if(pEvent->type == GDK_KEY_PRESS)
-	gtk_dasher_control_external_key_down(GTK_DASHER_CONTROL(pPrivate->pDasherWidget), iButton);
-      else
-	gtk_dasher_control_external_key_up(GTK_DASHER_CONTROL(pPrivate->pDasherWidget), iButton);
+
+    if(gdk_window_get_toplevel(pEvent->window) == pPrivate->pMainWindow->window) {
+      if(pPrivate->pDasherWidget) {
+	if(pEvent->type == GDK_KEY_PRESS)
+	  gtk_dasher_control_external_key_down(GTK_DASHER_CONTROL(pPrivate->pDasherWidget), iButton);
+	else
+	  gtk_dasher_control_external_key_up(GTK_DASHER_CONTROL(pPrivate->pDasherWidget), iButton);
+      }
+      
+      return TRUE;
+    }
+    else {
+      return FALSE;
     }
-    
-    return TRUE;
   }
   else {
     return FALSE;
